import {Text, View} from "@tarojs/components";
import {FC, useEffect, useState} from "react";
import styles from './userInfo.module.scss'
import Taro from "@tarojs/taro";
import Info from "@/pages/manage/userInfo/components/info";
import Tabs, {OnChangOpt, TabList} from "@/components/tabs/tabs";
import MyButton from "@/components/button/MyButton";
import {ManageApi, StatisticsParam, userApi} from "@/api";
import {Profile} from "@/store";
import {everyDay, formatMinute, getMonday, getSunday, monthEnd, monthFirst} from "@/utils/time";
import LineChart from "@/components/lineChart/lineChart";


const tabList: TabList<any>[] = [
  {
    title: '日',
    value: {
      start_time: new Date().setHours(0, 0, 0, 0),
      end_time: new Date().setHours(24, 0, 0, 0)
    }
  },
  {
    title: '周', value: {
      start_time: getMonday(),
      end_time: getSunday()
    }
  },
  {
    title: '月', value: {
      start_time: monthFirst(),
      end_time: monthEnd()
    }
  },
]

const UserInfo: FC = () => {
  const {userId} = Taro.getCurrentInstance().router?.params as { userId: string }
  const [data, setData] = useState<User | null>(null)
  const [lineData, setLineData] = useState<any[]>([])
  const router = Taro.useRouter()
  const {user} = Profile.useContainer()

  function setRoleType() {
    if (!data) return;
    if (data.role_type === 2) {
      Taro.showModal({title: "禁止修改超级管理员"})
      return
    }
    const type = data.role_type === 0 ? 1 : 0
    Taro.showModal({
      title: "设置为" + ['学员', '管理员'][type],
      async success({confirm}) {
        if (confirm) {
          try {
            await ManageApi.setRoleType(userId, {auth_id: user?.id!, role_type: type})
            Taro.showToast({title: "设置成功"})
            setData({
              ...data,
              role_type: type
            })
          } catch (e) {
          }
        }
      }
    })
  }

  function delUser() {
    Taro.showModal({
      title: '是否确认删除',
      async success({confirm}) {
        if (confirm) {
          try {
            await ManageApi.del(userId)
            Taro.showToast({title: '删除成功'})
            Taro.navigateBack()
          } catch (e) {
          }
        }
      }
    })
  }

  async function getStatistics(data: StatisticsParam) {
    try {
      const res = await userApi.statistics(userId, data)
      const everyDayValue = everyDay(data.start_time, Number(data.end_time), res.data)
      setLineData(everyDayValue)
    } catch (e) {

    }
  }

  function tabChange({tab}: OnChangOpt<StatisticsParam>) {
    getStatistics(tab?.value! as StatisticsParam)
  }

  useEffect(() => {
    getStatistics(tabList[0].value)
    userApi.info(userId).then(res => {
      setData(res)
    })
  }, [])

  Taro.useDidShow(() => {
    if (data) {
      userApi.info(router.params.userId!).then(res => {
        setData(res)
      })
    }
  })

  return (
    <View className={styles.page}>
      <Info data={data}/>

      <View className={`${styles.box} mt-3`} style={{display: 'block'}}>
        <Tabs tabList={tabList} onChange={tabChange}/>
        <View className='font-weight font-36 mt-5 mb-3'>
          总共学习
          <Text style={{margin: '0 10px', color: '#00D6AC'}}>
            {formatMinute(lineData.reduce((pre, cur) => pre + cur.value, 0) || 0)}
          </Text>
          分钟
        </View>
        <LineChart data={lineData}/>
      </View>


      <View className='mt-5'>
        {
          data?.role_type !== 2
          && <MyButton onClick={setRoleType}>{['设置为管理员', '设置为学员'][data?.role_type || 0]}</MyButton>
        }
        <MyButton
          type='default'
          style={{background: '#fff'}}
          onClick={() => Taro.navigateTo({url: "/pages/manage/addStudent/addStudent?id=" + userId})}
          className={'mt-3'}>
          修改
        </MyButton>
        <MyButton
          type='default'
          style={{background: '#fff', color: 'red'}}
          className={'mt-3'}
          onClick={delUser}>
          删除
        </MyButton>
      </View>
    </View>
  )
}

export default UserInfo
